# Model Feature Scan Report

_Report generated on: 2025-06-05T00:31:55.621375_

## API: OpenAIApi

### API Summary

* **Total Models Scanned:** 46
* **Average Supported Features per Model:** 2.35

#### Feature Support Across Models:

* Audio: 0.0% (0/46)
* AudioConversion: 0.0% (0/46)
* AudioEmbeddings: 6.5% (3/46)
* AudioGeneration: 6.5% (3/46)
* AudioTranscription: 4.3% (2/46)
* Document: 0.0% (0/46)
* DocumentConversion: 0.0% (0/46)
* DocumentEmbeddings: 6.5% (3/46)
* Image: 30.4% (14/46)
* ImageConversion: 0.0% (0/46)
* ImageEmbeddings: 6.5% (3/46)
* ImageGeneration: 6.5% (3/46)
* StructuredTextGeneration: 32.6% (15/46)
* TextEmbeddings: 6.5% (3/46)
* TextGeneration: 50.0% (23/46)
* Thinking: 28.3% (13/46)
* Tools: 43.5% (20/46)
* Video: 0.0% (0/46)
* VideoConversion: 0.0% (0/46)
* VideoEmbeddings: 6.5% (3/46)
* VideoGeneration: 0.0% (0/46)

### Model Details

#### Model: chatgpt-4o-latest (2/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: dall-e-2 (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ✅ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: dall-e-3 (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ✅ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: fastembed (5/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ✅ TextEmbeddings
* ✅ ImageEmbeddings
* ✅ AudioEmbeddings
* ✅ VideoEmbeddings
* ✅ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-3.5-turbo (2/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-3.5-turbo-16k (2/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-3.5-turbo-instruct (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4 (1/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4-32k (2/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4-turbo (3/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4-turbo-preview (2/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4.1 (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4.1-mini (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4.1-nano (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4.5-preview (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-audio-preview (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-audio-preview (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-realtime-preview (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-search-preview (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-transcribe (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-mini-tts (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ✅ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-realtime-preview (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-search-preview (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-4o-transcribe (0/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: gpt-image-1 (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ✅ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-high (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-low (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-medium (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-mini-high (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-mini-low (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-mini-medium (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o1-preview (2/21 features supported)

* ✅ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-high (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-low (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-medium (5/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ✅ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-mini-high (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-mini-low (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: o3-mini-medium (4/21 features supported)

* ✅ TextGeneration
* ✅ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ✅ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ✅ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: text-embedding-3-large (5/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ✅ TextEmbeddings
* ✅ ImageEmbeddings
* ✅ AudioEmbeddings
* ✅ VideoEmbeddings
* ✅ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: text-embedding-3-small (5/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ✅ TextEmbeddings
* ✅ ImageEmbeddings
* ✅ AudioEmbeddings
* ✅ VideoEmbeddings
* ✅ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: tts-1 (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ✅ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: tts-1-hd (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ✅ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ❌ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: whisper-1 (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ✅ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

#### Model: whisper-local (1/21 features supported)

* ❌ TextGeneration
* ❌ StructuredTextGeneration
* ❌ ImageGeneration
* ❌ AudioGeneration
* ❌ VideoGeneration
* ❌ Thinking
* ❌ TextEmbeddings
* ❌ ImageEmbeddings
* ❌ AudioEmbeddings
* ❌ VideoEmbeddings
* ❌ DocumentEmbeddings
* ❌ Image
* ❌ Audio
* ❌ Video
* ❌ Document
* ❌ Tools
* ✅ AudioTranscription
* ❌ ImageConversion
* ❌ AudioConversion
* ❌ VideoConversion
* ❌ DocumentConversion

_This report is auto-generated by Litemind. Some features may not be supported due to model limitations, API
restrictions, or potential bugs in Litemind._